@@ -15,7 +15,7 @@ package Image::ExifTool::Shortcuts;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '1.06';
+$VERSION = '1.19';
 
 # this is a special table used to define command-line shortcuts
 %Image::ExifTool::Shortcuts::Main = (
@@ -87,7 +87,7 @@ $VERSION = '1.06';
         'FocalLength',
         #'ImageSize', #wrong in CR2
         'ExifImageWidth', #instead
-        'ExifImageLength', #instead
+        'ExifImageHeight', #instead
         'Quality',
         'FlashOn',
         'FlashType',
@@ -138,28 +138,62 @@ $VERSION = '1.06';
         'FlashMode',
         'FlashExposureComp',
     ],
-    # This shortcut intends to remove tags which contain no useful
-    #  information given that the file was created with a Nikon D70.
-    # Use "--d70boring" to suppress tags in this list.
-    D70Boring => [
-        'Make',
-        'XResolution',
-        'YResolution',
-        'ResolutionUnit',
-        'YCbCrPositioning',
-        'FileSource',
-        'SceneType',
-        'ThumbnailOffset',
-        'ThumbnailLength',
-        'CreateDate',
-        'ComponentsConfiguration',
-        'InteropIndex',
-        'InteropVersion',
-        'SubSecTime',
-        'SubSecTimeDigitized',
-        'SensingMethod',
-        'CFAPattern',
-        'ThumbnailImageIFD',
+    # This shortcut may be useful when copying tags between files to either
+    # copy the maker notes as a block or prevent it from being copied
+    MakerNotes => [
+        'MakerNotes',   # (for RIFF MakerNotes)
+        'MakerNoteCanon',
+        'MakerNoteCasio',
+        'MakerNoteCasio2',
+        'MakerNoteFujiFilm',
+        'MakerNoteHP',
+        'MakerNoteHP2',
+        'MakerNoteHP4',
+        'MakerNoteHP6',
+        'MakerNoteISL',
+        'MakerNoteJVC',
+        'MakerNoteJVCText',
+        'MakerNoteKodak1a',
+        'MakerNoteKodak1b',
+        'MakerNoteKodak2',
+        'MakerNoteKodak3',
+        'MakerNoteKodak4',
+        'MakerNoteKodak5',
+        'MakerNoteKodak6a',
+        'MakerNoteKodak6b',
+        'MakerNoteKodak7',
+        'MakerNoteKodak8',
+        'MakerNoteKodakUnknown',
+        'MakerNoteKyocera',
+        'MakerNoteMinolta',
+        'MakerNoteMinolta2',
+        'MakerNoteMinolta3',
+        'MakerNoteNikon',
+        'MakerNoteNikon2',
+        'MakerNoteNikon3',
+        'MakerNoteOlympus',
+        'MakerNoteOlympus2',
+        'MakerNoteLeica',
+        'MakerNoteLeica2',
+        'MakerNoteLeica3',
+        'MakerNotePanasonic',
+        'MakerNotePanasonic2',
+        'MakerNotePentax',
+        'MakerNotePentax2',
+        'MakerNotePentax3',
+        'MakerNotePentax4',
+        'MakerNoteRicoh',
+        'MakerNoteRicohText',
+        'MakerNoteSanyo',
+        'MakerNoteSanyoC4',
+        'MakerNoteSanyoPatch',
+        'MakerNoteSigma',
+        'MakerNoteSony',
+        'MakerNoteSony2',
+        'MakerNoteSony3',
+        'MakerNoteSony4',
+        'MakerNoteSonySRF',
+        'MakerNoteUnknown',
     ],
 );
 
@@ -213,7 +247,7 @@ FocalLengthIn35mmFormat.
 
 =head1 AUTHOR
 
-Copyright 2003-2006, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2008, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
